@@ -452,8 +452,11 @@ procman_get_tree_state (GConfClient *client, GtkWidget *tree, const gchar *prefi
 			column = gtk_tree_view_get_column (GTK_TREE_VIEW (tree), id);
 			if(!column) continue;
 			gtk_tree_view_column_set_visible (column, visible);
-			if (width > 0)
-				gtk_tree_view_column_set_fixed_width (column, width);
+			if (visible) {
+				/* ensure column is really visible */
+				width = MAX(width, 10);
+				gtk_tree_view_column_set_fixed_width(column, width);
+			}
 		}
 	}
 
@@ -689,7 +692,7 @@ main (int argc, char *argv[])
 		exit (0);
 	}
 
-	gtk_window_set_default_icon_name ("gnome-monitor");
+	gtk_window_set_default_icon_name ("utilities-system-monitor");
 	g_set_application_name(_("System Monitor"));
 		    
 	gconf_init (argc, argv, NULL);
